scipy.sparse.dok_matrix
=======================

.. currentmodule:: scipy.sparse

.. autoclass:: dok_matrix

   

   .. HACK
      .. autosummary::
         :toctree:
      
         dok_matrix.__init__
         dok_matrix.asformat
         dok_matrix.asfptype
         dok_matrix.astype
         dok_matrix.clear
         dok_matrix.conj
         dok_matrix.conjtransp
         dok_matrix.conjugate
         dok_matrix.copy
         dok_matrix.diagonal
         dok_matrix.dot
         dok_matrix.get
         dok_matrix.getH
         dok_matrix.get_shape
         dok_matrix.getcol
         dok_matrix.getformat
         dok_matrix.getmaxprint
         dok_matrix.getnnz
         dok_matrix.getrow
         dok_matrix.has_key
         dok_matrix.items
         dok_matrix.iteritems
         dok_matrix.iterkeys
         dok_matrix.itervalues
         dok_matrix.keys
         dok_matrix.mean
         dok_matrix.multiply
         dok_matrix.nonzero
         dok_matrix.pop
         dok_matrix.popitem
         dok_matrix.reshape
         dok_matrix.resize
         dok_matrix.set_shape
         dok_matrix.setdefault
         dok_matrix.setdiag
         dok_matrix.split
         dok_matrix.sum
         dok_matrix.take
         dok_matrix.toarray
         dok_matrix.tobsr
         dok_matrix.tocoo
         dok_matrix.tocsc
         dok_matrix.tocsr
         dok_matrix.todense
         dok_matrix.todia
         dok_matrix.todok
         dok_matrix.tolil
         dok_matrix.transpose
         dok_matrix.update
         dok_matrix.values



   

   .. HACK
      .. autosummary::
         :toctree:
      
         dok_matrix.nnz
         dok_matrix.shape

